text module
-----------

.. automodule:: text
   :members:
   :undoc-members:
   :show-inheritance:

summary module
--------------

.. automodule:: summary
   :members:
   :undoc-members:
   :show-inheritance:

multimodal search module
------------------------

.. automodule:: multimodal_search
   :members:
   :undoc-members:
   :show-inheritance:

faces module
------------

.. automodule:: faces
   :members:
   :undoc-members:
   :show-inheritance:
   
color_analysis module
---------------------

.. automodule:: colors
   :members:
   :undoc-members:
   :show-inheritance:

cropposts module
----------------

.. automodule:: cropposts
   :members:
   :undoc-members:
   :show-inheritance:

utils module
------------

.. automodule:: utils
   :members:
   :undoc-members:
   :show-inheritance:

display module
--------------

.. automodule:: display
   :members:
   :undoc-members:
   :show-inheritance: